@@ -2,8 +2,7 @@ package LinkEmbedder::Link::AppearIn;
 use Mojo::Base 'LinkEmbedder::Link';
 
 has provider_name => 'AppearIn';
-has provider_url  => sub { Mojo::URL->new('https://appear.in') };
-has room          => undef;
+has provider_url => sub { Mojo::URL->new('https://appear.in') };
 
 sub learn {
   my ($self, $cb) = @_;
@@ -11,26 +10,15 @@ sub learn {
 
   return $self->SUPER::learn($cb) unless @$path == 1;
 
+  $self->{iframe_src} = "https://appear.in/$path->[0]";
   $self->height(390) unless $self->height;
   $self->width(740)  unless $self->width;
   $self->type('rich');
-  $self->room($path->[0]);
+  $self->template->[1] = 'iframe.html.ep';
   $self->title("Join the room $path->[0]");
 
   $self->$cb if $cb;
   return $self;
 }
 
-sub _template {
-  my $self = shift;
-  return $self->SUPER::_template(@_) unless $self->room;
-  return __PACKAGE__, 'rich.html.ep';
-}
-
 1;
-
-__DATA__
-@@ rich.html.ep
-<iframe width="<%= $l->width %>" height="<%= $l->height %>" style="border:0"
-  frameborder="0" src="https://appear.in/<%= $l->room %>">
-</iframe>
